# Getting Started
Iambic provides a simple, accessible high-level API for interacting
with structured text.

## Installation
Iambic is hosted on PyPI, so may be installed with the dependency
manager of your choosing. (pip, Poetry, Pipenv...)

## Using the Library
Using iambic is easy - just import it and go!
```
import iambic
```

The primary focus of the library is parsing pre-formatted text into a
useable data-structure. Continue reading for more insights!
